@@ -1,6 +1,5 @@
-# This file was created automatically by SWIG.
+# This file was created automatically by SWIG 1.3.27.
 # Don't modify this file, modify the SWIG interface instead.
-# This file is compatible with both classic and new-style classes.
 
 import _usrp0
 
@@ -36,12 +35,17 @@ except AttributeError:
 del types
 
 
-class usrp0_sink_c_sptr(_object):
+def _swig_setattr_nondynamic_method(set):
+    def set_attr(self,name,value):
+        if hasattr(self,name) or (name in ("this", "thisown")):
+            set(self,name,value)
+        else:
+            raise AttributeError("You cannot add attributes to %s" % self)
+    return set_attr
+
+
+class usrp0_sink_c_sptr(object):
     """Proxy of C++ usrp0_sink_c_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, usrp0_sink_c_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, usrp0_sink_c_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<usrp0_sink_c > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -49,69 +53,83 @@ class usrp0_sink_c_sptr(_object):
         __init__(self) -> usrp0_sink_c_sptr
         __init__(self,  p) -> usrp0_sink_c_sptr
         """
-        _swig_setattr(self, usrp0_sink_c_sptr, 'this', _usrp0.new_usrp0_sink_c_sptr(*args))
-        _swig_setattr(self, usrp0_sink_c_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _usrp0.new_usrp0_sink_c_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _usrp0.usrp0_sink_c_sptr___deref__(*args)
 
-    def set_interp_rate(*args): 
+    def set_interp_rate(*args):
         """set_interp_rate(self, unsigned int rate) -> bool"""
         return _usrp0.usrp0_sink_c_sptr_set_interp_rate(*args)
 
-    def set_tx_freq(*args): 
+    def set_tx_freq(*args):
         """set_tx_freq(self, int channel, double freq) -> bool"""
         return _usrp0.usrp0_sink_c_sptr_set_tx_freq(*args)
 
-    def dac_freq(*args): 
+    def dac_freq(*args):
         """dac_freq(self) -> long"""
         return _usrp0.usrp0_sink_c_sptr_dac_freq(*args)
 
-    def interp_rate(*args): 
+    def interp_rate(*args):
         """interp_rate(self) -> unsigned int"""
         return _usrp0.usrp0_sink_c_sptr_interp_rate(*args)
 
-    def tx_freq(*args): 
+    def tx_freq(*args):
         """tx_freq(self, int channel) -> double"""
         return _usrp0.usrp0_sink_c_sptr_tx_freq(*args)
 
-    def nunderruns(*args): 
+    def nunderruns(*args):
         """nunderruns(self) -> int"""
         return _usrp0.usrp0_sink_c_sptr_nunderruns(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _usrp0.usrp0_sink_c_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _usrp0.usrp0_sink_c_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _usrp0.usrp0_sink_c_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _usrp0.usrp0_sink_c_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _usrp0.usrp0_sink_c_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _usrp0.usrp0_sink_c_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _usrp0.usrp0_sink_c_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _usrp0.usrp0_sink_c_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _usrp0.usrp0_sink_c_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _usrp0.usrp0_sink_c_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _usrp0.usrp0_sink_c_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _usrp0.usrp0_sink_c_sptr_set_detail(*args)
 
@@ -124,9 +142,9 @@ class usrp0_sink_c_sptr(_object):
 
 class usrp0_sink_c_sptrPtr(usrp0_sink_c_sptr):
     def __init__(self, this):
-        _swig_setattr(self, usrp0_sink_c_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, usrp0_sink_c_sptr, 'thisown', 0)
-        _swig_setattr(self, usrp0_sink_c_sptr,self.__class__,usrp0_sink_c_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = usrp0_sink_c_sptr
 _usrp0.usrp0_sink_c_sptr_swigregister(usrp0_sink_c_sptrPtr)
 
 
@@ -140,12 +158,8 @@ usrp0_sink_c_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), s
 def sink_c(*args):
     """sink_c(int which_board, unsigned int interp_rate) -> usrp0_sink_c_sptr"""
     return _usrp0.sink_c(*args)
-class usrp0_source_c_sptr(_object):
+class usrp0_source_c_sptr(object):
     """Proxy of C++ usrp0_source_c_sptr class"""
-    __swig_setmethods__ = {}
-    __setattr__ = lambda self, name, value: _swig_setattr(self, usrp0_source_c_sptr, name, value)
-    __swig_getmethods__ = {}
-    __getattr__ = lambda self, name: _swig_getattr(self, usrp0_source_c_sptr, name)
     def __repr__(self):
         return "<%s.%s; proxy of C++ boost::shared_ptr<usrp0_source_c > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
     def __init__(self, *args):
@@ -153,77 +167,91 @@ class usrp0_source_c_sptr(_object):
         __init__(self) -> usrp0_source_c_sptr
         __init__(self,  p) -> usrp0_source_c_sptr
         """
-        _swig_setattr(self, usrp0_source_c_sptr, 'this', _usrp0.new_usrp0_source_c_sptr(*args))
-        _swig_setattr(self, usrp0_source_c_sptr, 'thisown', 1)
-    def __deref__(*args): 
+        newobj = _usrp0.new_usrp0_source_c_sptr(*args)
+        self.this = newobj.this
+        self.thisown = 1
+        del newobj.thisown
+    def __deref__(*args):
         """__deref__(self)"""
         return _usrp0.usrp0_source_c_sptr___deref__(*args)
 
-    def set_decim_rate(*args): 
+    def set_decim_rate(*args):
         """set_decim_rate(self, unsigned int rate) -> bool"""
         return _usrp0.usrp0_source_c_sptr_set_decim_rate(*args)
 
-    def set_rx_freq(*args): 
+    def set_rx_freq(*args):
         """set_rx_freq(self, int channel, double freq) -> bool"""
         return _usrp0.usrp0_source_c_sptr_set_rx_freq(*args)
 
-    def set_adc_clk_div(*args): 
+    def set_adc_clk_div(*args):
         """set_adc_clk_div(self, unsigned int div) -> bool"""
         return _usrp0.usrp0_source_c_sptr_set_adc_clk_div(*args)
 
-    def adc_freq(*args): 
+    def adc_freq(*args):
         """adc_freq(self) -> long"""
         return _usrp0.usrp0_source_c_sptr_adc_freq(*args)
 
-    def decim_rate(*args): 
+    def decim_rate(*args):
         """decim_rate(self) -> unsigned int"""
         return _usrp0.usrp0_source_c_sptr_decim_rate(*args)
 
-    def rx_freq(*args): 
+    def rx_freq(*args):
         """rx_freq(self, int channel) -> double"""
         return _usrp0.usrp0_source_c_sptr_rx_freq(*args)
 
-    def noverruns(*args): 
+    def noverruns(*args):
         """noverruns(self) -> int"""
         return _usrp0.usrp0_source_c_sptr_noverruns(*args)
 
-    def adc_clk_div(*args): 
+    def adc_clk_div(*args):
         """adc_clk_div(self) -> unsigned int"""
         return _usrp0.usrp0_source_c_sptr_adc_clk_div(*args)
 
-    def name(*args): 
+    def name(*args):
         """name(self) -> string"""
         return _usrp0.usrp0_source_c_sptr_name(*args)
 
-    def input_signature(*args): 
+    def input_signature(*args):
         """input_signature(self) -> gr_io_signature_sptr"""
         return _usrp0.usrp0_source_c_sptr_input_signature(*args)
 
-    def output_signature(*args): 
+    def output_signature(*args):
         """output_signature(self) -> gr_io_signature_sptr"""
         return _usrp0.usrp0_source_c_sptr_output_signature(*args)
 
-    def unique_id(*args): 
+    def unique_id(*args):
         """unique_id(self) -> long"""
         return _usrp0.usrp0_source_c_sptr_unique_id(*args)
 
-    def output_multiple(*args): 
+    def history(*args):
+        """history(self) -> unsigned int"""
+        return _usrp0.usrp0_source_c_sptr_history(*args)
+
+    def output_multiple(*args):
         """output_multiple(self) -> int"""
         return _usrp0.usrp0_source_c_sptr_output_multiple(*args)
 
-    def relative_rate(*args): 
+    def relative_rate(*args):
         """relative_rate(self) -> double"""
         return _usrp0.usrp0_source_c_sptr_relative_rate(*args)
 
-    def check_topology(*args): 
+    def check_topology(*args):
         """check_topology(self, int ninputs, int noutputs) -> bool"""
         return _usrp0.usrp0_source_c_sptr_check_topology(*args)
 
-    def detail(*args): 
+    def start(*args):
+        """start(self) -> bool"""
+        return _usrp0.usrp0_source_c_sptr_start(*args)
+
+    def stop(*args):
+        """stop(self) -> bool"""
+        return _usrp0.usrp0_source_c_sptr_stop(*args)
+
+    def detail(*args):
         """detail(self) -> gr_block_detail_sptr"""
         return _usrp0.usrp0_source_c_sptr_detail(*args)
 
-    def set_detail(*args): 
+    def set_detail(*args):
         """set_detail(self, gr_block_detail_sptr detail)"""
         return _usrp0.usrp0_source_c_sptr_set_detail(*args)
 
@@ -236,9 +264,9 @@ class usrp0_source_c_sptr(_object):
 
 class usrp0_source_c_sptrPtr(usrp0_source_c_sptr):
     def __init__(self, this):
-        _swig_setattr(self, usrp0_source_c_sptr, 'this', this)
-        if not hasattr(self,"thisown"): _swig_setattr(self, usrp0_source_c_sptr, 'thisown', 0)
-        _swig_setattr(self, usrp0_source_c_sptr,self.__class__,usrp0_source_c_sptr)
+        self.this = this
+        if not hasattr(self,"thisown"): self.thisown = 0
+        self.__class__ = usrp0_source_c_sptr
 _usrp0.usrp0_source_c_sptr_swigregister(usrp0_source_c_sptrPtr)
 
 
@@ -253,3 +281,4 @@ def source_c(*args):
     """source_c(int which_board, unsigned int decim_rate) -> usrp0_source_c_sptr"""
     return _usrp0.source_c(*args)
 
+
