@@ -28,8 +28,7 @@
 #include <gr_io_signature.h>
 #include <usrp_standard.h>
 
-static const int NUSRP_BYTES_PER_ITEM = 2 * sizeof (short);
-
+static const int NBASIC_SAMPLES_PER_ITEM = 2;	// I & Q
 
 usrp1_source_c_sptr
 usrp1_make_source_c (int which_board,
@@ -67,11 +66,11 @@ usrp1_source_c::~usrp1_source_c ()
 int
 usrp1_source_c::ninput_bytes_reqd_for_noutput_items (int noutput_items)
 {
-  return noutput_items * NUSRP_BYTES_PER_ITEM;
+  return noutput_items * NBASIC_SAMPLES_PER_ITEM * sizeof_basic_sample();
 }
 
 /*
- * Convert interleaved 16-bit I & Q from usrp buffer into a single
+ * Convert interleaved 8 or 16-bit I & Q from usrp buffer into a single
  * complex output stream.
  */
 void
@@ -84,15 +83,32 @@ usrp1_source_c::copy_from_usrp_buffer (gr_vector_void_star &output_items,
 				       int &bytes_read)
 {
   gr_complex *out = &((gr_complex *) output_items[0])[output_index];
-  short *src = (short *) usrp_buffer;
+  unsigned sbs = sizeof_basic_sample();
+  unsigned nusrp_bytes_per_item = NBASIC_SAMPLES_PER_ITEM * sbs;
 
   int nitems = std::min (output_items_available,
-			 usrp_buffer_length / NUSRP_BYTES_PER_ITEM);
+			 (int)(usrp_buffer_length / nusrp_bytes_per_item));
 
-  for (int i = 0; i < nitems; i++){
-    out[i] = gr_complex ((float) src[2*i + 0], (float) src[2*i + 1]);
+  signed char *s8 = (signed char *) usrp_buffer;
+  short *s16 = (short *) usrp_buffer;
+
+  switch (sbs){
+  case 1:
+    for (int i = 0; i < nitems; i++){
+      out[i] = gr_complex ((float)(s8[2*i+0] << 8), (float)(s8[2*i+1] << 8));
+    }
+    break;
+
+  case 2:
+    for (int i = 0; i < nitems; i++){
+      out[i] = gr_complex ((float) s16[2*i+0], (float) s16[2*i+1]);
+    }
+    break;
+
+  default:
+    assert(0);
   }
 
   output_items_produced = nitems;
-  bytes_read = nitems * NUSRP_BYTES_PER_ITEM;
+  bytes_read = nitems * nusrp_bytes_per_item;
 }
