@@ -28,8 +28,7 @@
 #include <gr_io_signature.h>
 #include <usrp_standard.h>
 
-static const int NUSRP_BYTES_PER_ITEM = 1 * sizeof (short);
-
+static const int NBASIC_SAMPLES_PER_ITEM = 1;
 
 usrp1_source_s_sptr
 usrp1_make_source_s (int which_board, 
@@ -67,11 +66,11 @@ usrp1_source_s::~usrp1_source_s ()
 int
 usrp1_source_s::ninput_bytes_reqd_for_noutput_items (int noutput_items)
 {
-  return noutput_items * NUSRP_BYTES_PER_ITEM;
+  return noutput_items * NBASIC_SAMPLES_PER_ITEM * sizeof_basic_sample();
 }
 
 /*
- * Convert interleaved 16-bit I & Q from usrp buffer into a single
+ * Convert interleaved 8 or 16-bit I & Q from usrp buffer into a single
  * short output stream.
  */
 void
@@ -84,15 +83,32 @@ usrp1_source_s::copy_from_usrp_buffer (gr_vector_void_star &output_items,
 				       int &bytes_read)
 {
   short *out = &((short *) output_items[0])[output_index];
-  short *src = (short *) usrp_buffer;
+  unsigned sbs = sizeof_basic_sample();
+  unsigned nusrp_bytes_per_item = NBASIC_SAMPLES_PER_ITEM * sbs;
 
   int nitems = std::min (output_items_available,
-			 usrp_buffer_length / NUSRP_BYTES_PER_ITEM);
+			 (int)(usrp_buffer_length / nusrp_bytes_per_item));
 
-  for (int i = 0; i < nitems; i++){
-    out[i] = src[i];
+  signed char *s8 = (signed char *) usrp_buffer;
+  short *s16 = (short *) usrp_buffer;
+
+  switch(sbs){
+  case 1:
+    for (int i = 0; i < nitems; i++){
+      out[i] = s8[i] << 8;
+    }
+    break;
+
+  case 2:
+    for (int i = 0; i < nitems; i++){
+      out[i] = s16[i];
+    }
+    break;
+    
+  default:
+    assert(0);
   }
 
   output_items_produced = nitems;
-  bytes_read = nitems * NUSRP_BYTES_PER_ITEM;
+  bytes_read = nitems * nusrp_bytes_per_item;
 }
